# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.is_success import IsSuccess
from ...types.page_identifier import PageIdentifier
from ...types.response_text import ResponseText
from ...types.responsecode import Responsecode
from ...types.responsedatanonobject import Responsedatanonobject
from ...types.room_id_not_in_use import RoomIdNotInUse


class InvoiceResponseWithoutData(UniversalBaseModel):
    """
    Response schema for invoice operations.
    """

    is_success: typing_extensions.Annotated[IsSuccess, FieldMetadata(alias="isSuccess")]
    response_code: typing_extensions.Annotated[Responsecode, FieldMetadata(alias="responseCode")]
    response_data: typing_extensions.Annotated[Responsedatanonobject, FieldMetadata(alias="responseData")] = (
        pydantic.Field()
    )
    """
    If `isSuccess` = true, this contains the identifier of the invoice. If `isSuccess` = false, this contains the reason for the failure.
    """

    response_text: typing_extensions.Annotated[ResponseText, FieldMetadata(alias="responseText")]
    pageidentifier: typing.Optional[PageIdentifier] = None
    room_id: typing_extensions.Annotated[RoomIdNotInUse, FieldMetadata(alias="roomId")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
