# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.file_content_ftype import FileContentFtype


class FileContentImageOnly(UniversalBaseModel):
    ftype: typing.Optional[FileContentFtype] = None
    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the file to be uploaded
    """

    furl: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional URL link to the file
    """

    f_content: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="fContent")] = pydantic.Field(
        default=None
    )
    """
    Base64-encoded file content
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
