# This file was auto-generated by Fern from our API Definition.

import typing

Frequency = typing.Union[
    typing.Literal["one-time", "weekly", "every2weeks", "every6months", "monthly", "every3months", "annually"],
    typing.Any,
]
