# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .template_additional_data_section import TemplateAdditionalDataSection
from .template_element import TemplateElement
from .visible import Visible


class SignerSection(UniversalBaseModel):
    visible: typing.Optional[Visible] = None
    name: typing.Optional[TemplateElement] = None
    ssn: typing.Optional[TemplateElement] = None
    dob: typing.Optional[TemplateElement] = None
    phone: typing.Optional[TemplateElement] = None
    email: typing.Optional[TemplateElement] = None
    address: typing.Optional[TemplateElement] = None
    address_1: typing_extensions.Annotated[typing.Optional[TemplateElement], FieldMetadata(alias="address1")] = None
    city: typing.Optional[TemplateElement] = None
    country: typing.Optional[TemplateElement] = None
    state: typing.Optional[TemplateElement] = None
    zip: typing.Optional[TemplateElement] = None
    acceptance: typing.Optional[TemplateElement] = None
    signed_document_reference: typing_extensions.Annotated[
        typing.Optional[TemplateElement], FieldMetadata(alias="signedDocumentReference")
    ] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[TemplateAdditionalDataSection], FieldMetadata(alias="additionalData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
