# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .sales_code import SalesCode


class SalesSection(UniversalBaseModel):
    sales_code: typing_extensions.Annotated[typing.Optional[SalesCode], FieldMetadata(alias="salesCode")] = None
    sales_crm: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="salesCRM")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
