# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ach_setup import AchSetup
from .card_setup import CardSetup
from .odp_setup import OdpSetup


class Services(UniversalBaseModel):
    """
    Controls which services will be enabled for the merchant.
    """

    ach: typing.Optional[AchSetup] = None
    card: typing.Optional[CardSetup] = None
    odp: typing.Optional[OdpSetup] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
