# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .order import Order


class PayCategory(UniversalBaseModel):
    description: typing.Optional[str] = None
    label: typing.Optional[str] = None
    name: typing.Optional[str] = None
    optional_pay: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="optionalPay")] = None
    order: typing.Optional[Order] = None
    quantity: typing.Optional[int] = None
    show_description: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="showDescription")] = None
    type: typing.Optional[str] = None
    value: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
