# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.notification_report_request import NotificationReportRequest
from ...types.notification_standard_request import NotificationStandardRequest

AddNotificationRequest = typing.Union[NotificationStandardRequest, NotificationReportRequest]
