# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...types.payabli_api_response_generic_2_part import PayabliApiResponseGeneric2Part


class ModifyApprovalBillResponse(PayabliApiResponseGeneric2Part):
    response_data: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="responseData")] = (
        pydantic.Field(default=None)
    )
    """
    If `isSuccess` = true, this contains the bill identifier. If `isSuccess` = false, this contains the reason for the error. 
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
