# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.api_error import ApiError
from ..types.payabli_api_response_paylinks import PayabliApiResponsePaylinks


class ConflictError(ApiError):
    def __init__(self, body: PayabliApiResponsePaylinks, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=409, headers=headers, body=body)
