# This file was auto-generated by Fern from our API Definition.

import typing

from .split_funding_content import SplitFundingContent

SplitFunding = typing.Optional[typing.List[SplitFundingContent]]
