# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AuthCapturePayoutResponse,
        AuthCapturePayoutResponseData,
        AuthorizePaymentMethod,
        AuthorizePayoutBody,
        CaptureAllOutResponse,
        CaptureAllOutResponseResponseDataItem,
        LotNumber,
        OperationResult,
        RequestOutAuthorizeInvoiceData,
        RequestOutAuthorizePaymentDetails,
        RequestOutAuthorizeVendorBillingData,
        RequestOutAuthorizeVendorData,
        RequestOutAuthorizeVendorDataOld,
        VCardGetResponse,
        VCardGetResponseAssociatedVendor,
        VCardGetResponseAssociatedVendorBillingData,
        VCardGetResponseAssociatedVendorSummary,
        VCardGetResponseContact,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AuthCapturePayoutResponse": ".types",
    "AuthCapturePayoutResponseData": ".types",
    "AuthorizePaymentMethod": ".types",
    "AuthorizePayoutBody": ".types",
    "CaptureAllOutResponse": ".types",
    "CaptureAllOutResponseResponseDataItem": ".types",
    "LotNumber": ".types",
    "OperationResult": ".types",
    "RequestOutAuthorizeInvoiceData": ".types",
    "RequestOutAuthorizePaymentDetails": ".types",
    "RequestOutAuthorizeVendorBillingData": ".types",
    "RequestOutAuthorizeVendorData": ".types",
    "RequestOutAuthorizeVendorDataOld": ".types",
    "VCardGetResponse": ".types",
    "VCardGetResponseAssociatedVendor": ".types",
    "VCardGetResponseAssociatedVendorBillingData": ".types",
    "VCardGetResponseAssociatedVendorSummary": ".types",
    "VCardGetResponseContact": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AuthCapturePayoutResponse",
    "AuthCapturePayoutResponseData",
    "AuthorizePaymentMethod",
    "AuthorizePayoutBody",
    "CaptureAllOutResponse",
    "CaptureAllOutResponseResponseDataItem",
    "LotNumber",
    "OperationResult",
    "RequestOutAuthorizeInvoiceData",
    "RequestOutAuthorizePaymentDetails",
    "RequestOutAuthorizeVendorBillingData",
    "RequestOutAuthorizeVendorData",
    "RequestOutAuthorizeVendorDataOld",
    "VCardGetResponse",
    "VCardGetResponseAssociatedVendor",
    "VCardGetResponseAssociatedVendorBillingData",
    "VCardGetResponseAssociatedVendorSummary",
    "VCardGetResponseContact",
]
