# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .policy_id import PolicyId
from .under_writing_method import UnderWritingMethod


class UnderwritingData(UniversalBaseModel):
    """
    Underwriting data is used to manage risk orchestration in the boarding application lifecycle.
    """

    method: UnderWritingMethod
    policy_id: typing_extensions.Annotated[typing.Optional[PolicyId], FieldMetadata(alias="policyId")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
