# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class VCardGetResponseContact(UniversalBaseModel):
    """
    Contact information structure.
    """

    contact_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactName")] = (
        pydantic.Field(default=None)
    )
    """
    Name of the contact.
    """

    contact_email: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Email of the contact.
    """

    contact_title: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactTitle")] = (
        pydantic.Field(default=None)
    )
    """
    Title of the contact.
    """

    contact_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactPhone")] = (
        pydantic.Field(default=None)
    )
    """
    Phone number of the contact.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
