# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_invoice_record import GetInvoiceRecord
    from .invoice_data_request import InvoiceDataRequest
    from .invoice_id import InvoiceId
    from .invoice_number_response import InvoiceNumberResponse
    from .invoice_paid_amount import InvoicePaidAmount
    from .invoice_response_without_data import InvoiceResponseWithoutData
    from .query_invoice_response import QueryInvoiceResponse
    from .query_invoice_response_records_item import QueryInvoiceResponseRecordsItem
    from .send_invoice_response import SendInvoiceResponse
_dynamic_imports: typing.Dict[str, str] = {
    "GetInvoiceRecord": ".get_invoice_record",
    "InvoiceDataRequest": ".invoice_data_request",
    "InvoiceId": ".invoice_id",
    "InvoiceNumberResponse": ".invoice_number_response",
    "InvoicePaidAmount": ".invoice_paid_amount",
    "InvoiceResponseWithoutData": ".invoice_response_without_data",
    "QueryInvoiceResponse": ".query_invoice_response",
    "QueryInvoiceResponseRecordsItem": ".query_invoice_response_records_item",
    "SendInvoiceResponse": ".send_invoice_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetInvoiceRecord",
    "InvoiceDataRequest",
    "InvoiceId",
    "InvoiceNumberResponse",
    "InvoicePaidAmount",
    "InvoiceResponseWithoutData",
    "QueryInvoiceResponse",
    "QueryInvoiceResponseRecordsItem",
    "SendInvoiceResponse",
]
