# This file was auto-generated by Fern from our API Definition.

import typing

from .cash import Cash
from .check import Check
from .pay_method_ach import PayMethodAch
from .pay_method_body_all_fields import PayMethodBodyAllFields
from .pay_method_cloud import PayMethodCloud
from .pay_method_credit import PayMethodCredit
from .pay_method_stored_method import PayMethodStoredMethod

PaymentMethod = typing.Union[
    PayMethodCredit, PayMethodAch, PayMethodStoredMethod, PayMethodCloud, Check, Cash, PayMethodBodyAllFields
]
