# This file was auto-generated by Fern from our API Definition.

import typing

MethodElementSettingsApplePayButtonType = typing.Union[
    typing.Literal[
        "plain",
        "buy",
        "donate",
        "check-out",
        "book",
        "continue",
        "top-up",
        "order",
        "rent",
        "support",
        "contribute",
        "tip",
        "pay",
    ],
    typing.Any,
]
