# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .file_content_image_only import FileContentImageOnly
    from .ocr_attachment import OcrAttachment
    from .ocr_bill_item import OcrBillItem
    from .ocr_bill_item_additional_data import OcrBillItemAdditionalData
    from .ocr_response_data import OcrResponseData
    from .ocr_result_data import OcrResultData
    from .ocr_vendor import OcrVendor
    from .ocr_vendor_additional_data import OcrVendorAdditionalData
    from .ocr_vendor_billing_data import OcrVendorBillingData
    from .payabli_api_response_ocr import PayabliApiResponseOcr
    from .type_result import TypeResult
_dynamic_imports: typing.Dict[str, str] = {
    "FileContentImageOnly": ".file_content_image_only",
    "OcrAttachment": ".ocr_attachment",
    "OcrBillItem": ".ocr_bill_item",
    "OcrBillItemAdditionalData": ".ocr_bill_item_additional_data",
    "OcrResponseData": ".ocr_response_data",
    "OcrResultData": ".ocr_result_data",
    "OcrVendor": ".ocr_vendor",
    "OcrVendorAdditionalData": ".ocr_vendor_additional_data",
    "OcrVendorBillingData": ".ocr_vendor_billing_data",
    "PayabliApiResponseOcr": ".payabli_api_response_ocr",
    "TypeResult": ".type_result",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "FileContentImageOnly",
    "OcrAttachment",
    "OcrBillItem",
    "OcrBillItemAdditionalData",
    "OcrResponseData",
    "OcrResultData",
    "OcrVendor",
    "OcrVendorAdditionalData",
    "OcrVendorBillingData",
    "PayabliApiResponseOcr",
    "TypeResult",
]
