# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.authcode import Authcode
from ...types.avsresponsetext import Avsresponsetext
from ...types.customeridtrans import Customeridtrans
from ...types.cvvresponsetext import Cvvresponsetext
from ...types.method_reference_id import MethodReferenceId
from ...types.referenceidtrans import Referenceidtrans
from ...types.result_code import ResultCode
from ...types.resulttext import Resulttext


class VoidResponseData(UniversalBaseModel):
    """
    Response data for void transactions
    """

    auth_code: typing_extensions.Annotated[Authcode, FieldMetadata(alias="authCode")]
    reference_id: typing_extensions.Annotated[Referenceidtrans, FieldMetadata(alias="referenceId")]
    result_code: typing_extensions.Annotated[ResultCode, FieldMetadata(alias="resultCode")]
    result_text: typing_extensions.Annotated[Resulttext, FieldMetadata(alias="resultText")]
    avs_response_text: typing_extensions.Annotated[
        typing.Optional[Avsresponsetext], FieldMetadata(alias="avsResponseText")
    ] = None
    cvv_response_text: typing_extensions.Annotated[
        typing.Optional[Cvvresponsetext], FieldMetadata(alias="cvvResponseText")
    ] = None
    customer_id: typing_extensions.Annotated[typing.Optional[Customeridtrans], FieldMetadata(alias="customerId")] = None
    method_reference_id: typing_extensions.Annotated[
        typing.Optional[MethodReferenceId], FieldMetadata(alias="methodReferenceId")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
