# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .enabled import Enabled


class ServiceCost(UniversalBaseModel):
    description: typing.Optional[str] = None
    enabled: typing.Optional[Enabled] = None
    monthly_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="monthlyCost")] = None
    name: typing.Optional[str] = None
    reseller: typing.Optional[bool] = None
    setup_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="setupCost")] = None
    tx_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="txCost")] = None
    tx_percent_cost: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="txPercentCost")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
