# This file was auto-generated by Fern from our API Definition.

import typing

BillDataPaymentTerms = typing.Union[
    typing.Literal[
        "PIA",
        "CIA",
        "UR",
        "NET10",
        "NET20",
        "NET30",
        "NET45",
        "NET60",
        "NET90",
        "EOM",
        "MFI",
        "5MFI",
        "10MFI",
        "15MFI",
        "20MFI",
        "2/10NET30",
        "UF",
        "10UF",
        "20UF",
        "25UF",
        "50UF",
    ],
    typing.Any,
]
