# This file was auto-generated by Fern from our API Definition.

import typing

Frequencynotification = typing.Union[
    typing.Literal[
        "one-time", "daily", "weekly", "biweekly", "monthly", "quarterly", "semiannually", "annually", "untilcancelled"
    ],
    typing.Any,
]
