# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class SplitFundingRefundContent(UniversalBaseModel):
    account_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="accountId")] = pydantic.Field(
        default=None
    )
    """
    The accountId for the account the transaction was routed to.
    """

    amount: typing.Optional[float] = pydantic.Field(default=None)
    """
    The amount to refund to this account.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Refund description.
    """

    origination_entry_point: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="originationEntryPoint")
    ] = pydantic.Field(default=None)
    """
    The entrypoint the transaction belongs to.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
