# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class BillOptions(UniversalBaseModel):
    include_paylink: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="includePaylink")] = (
        pydantic.Field(default=None)
    )
    """
    Flag to indicate if the scheduled invoice includes a payment link.
    """

    include_pdf: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="includePdf")] = pydantic.Field(
        default=None
    )
    """
    Flag to indicate if the scheduled invoice includes a PDF version of invoice
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
