# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .tier_item import TierItem


class CardType(UniversalBaseModel):
    amex: typing.Optional[TierItem] = None
    discover: typing.Optional[TierItem] = None
    master_card: typing_extensions.Annotated[typing.Optional[TierItem], FieldMetadata(alias="masterCard")] = None
    visa: typing.Optional[TierItem] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
