# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.application_data import ApplicationData
from ...types.application_data_managed import ApplicationDataManaged
from ...types.application_data_odp import ApplicationDataOdp
from ...types.application_data_pay_in import ApplicationDataPayIn

AddApplicationRequest = typing.Union[ApplicationDataPayIn, ApplicationDataManaged, ApplicationDataOdp, ApplicationData]
