# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class DisplayProperty(UniversalBaseModel):
    display: typing.Optional[bool] = pydantic.Field(default=None)
    """
    When `true`, the field is displayed on the receipt.
    """

    fixed: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="Fixed")] = pydantic.Field(
        default=None
    )
    """
    This field is unused.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The field's name.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
