# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.pay_method_cloud import PayMethodCloud
from ...types.pay_method_credit import PayMethodCredit
from ...types.pay_method_stored_method import PayMethodStoredMethod

RequestPaymentAuthorizePaymentMethod = typing.Union[PayMethodCredit, PayMethodStoredMethod, PayMethodCloud]
