# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .is_success import IsSuccess
from .page_identifier import PageIdentifier
from .payment_method_domain_api_response import PaymentMethodDomainApiResponse


class AddPaymentMethodDomainApiResponse(UniversalBaseModel):
    """
    Response for the add payment method domain operation.
    """

    is_success: typing_extensions.Annotated[IsSuccess, FieldMetadata(alias="isSuccess")]
    pageidentifier: PageIdentifier
    response_data: typing_extensions.Annotated[PaymentMethodDomainApiResponse, FieldMetadata(alias="responseData")]
    response_text: typing_extensions.Annotated[str, FieldMetadata(alias="responseText")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
