# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .link_data import LinkData


class CList(UniversalBaseModel):
    contact_email: typing_extensions.Annotated[typing.Optional[LinkData], FieldMetadata(alias="contactEmail")] = None
    contact_name: typing_extensions.Annotated[typing.Optional[LinkData], FieldMetadata(alias="contactName")] = None
    contact_phone: typing_extensions.Annotated[typing.Optional[LinkData], FieldMetadata(alias="contactPhone")] = None
    contact_title: typing_extensions.Annotated[typing.Optional[LinkData], FieldMetadata(alias="contactTitle")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
