# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .application_data_pay_in_services_ach import ApplicationDataPayInServicesAch
from .application_data_pay_in_services_card import ApplicationDataPayInServicesCard
from .odp_setup import OdpSetup


class ApplicationDataPayInServices(UniversalBaseModel):
    ach: ApplicationDataPayInServicesAch
    card: ApplicationDataPayInServicesCard
    odp: typing.Optional[OdpSetup] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
