# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .ach_link_types import AchLinkTypes
from .basic_table import BasicTable


class AchSection(UniversalBaseModel):
    acceptance: typing.Optional[AchLinkTypes] = None
    fees: typing.Optional[BasicTable] = None
    price: typing.Optional[BasicTable] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
