# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.pay_method_ach import PayMethodAch
from ...types.pay_method_credit import PayMethodCredit
from .request_schedule_payment_method_initiator import RequestSchedulePaymentMethodInitiator

RequestSchedulePaymentMethod = typing.Union[PayMethodCredit, PayMethodAch, RequestSchedulePaymentMethodInitiator]
