# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoogleWalletData(UniversalBaseModel):
    """
    The wallet data.
    """

    gateway_merchant_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="gatewayMerchantId")] = (
        pydantic.Field(default=None)
    )
    """
    The Google Pay merchant identifier.
    """

    gateway_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="gatewayId")] = pydantic.Field(
        default=None
    )
    """
    The Google Pay gateway identifier.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
