# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...types.payabli_api_response_generic_2_part import PayabliApiResponseGeneric2Part
from .get_pay_link_from_id_response_response_data import GetPayLinkFromIdResponseResponseData


class GetPayLinkFromIdResponse(PayabliApiResponseGeneric2Part):
    response_data: typing_extensions.Annotated[
        typing.Optional[GetPayLinkFromIdResponseResponseData], FieldMetadata(alias="responseData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
