# This file was auto-generated by Fern from our API Definition.

import typing

from .convert_token import ConvertToken
from .tokenize_ach import TokenizeAch
from .tokenize_card import TokenizeCard

RequestTokenStoragePaymentMethod = typing.Union[TokenizeCard, TokenizeAch, ConvertToken]
