# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .link_data import LinkData


class BDetails(UniversalBaseModel):
    btype: typing.Optional[LinkData] = None
    dbaname: typing.Optional[LinkData] = None
    ein: typing.Optional[LinkData] = None
    faxnumber: typing.Optional[LinkData] = None
    legalname: typing.Optional[LinkData] = None
    license: typing.Optional[LinkData] = None
    licstate: typing.Optional[LinkData] = None
    phonenumber: typing.Optional[LinkData] = None
    startdate: typing.Optional[LinkData] = None
    taxfillname: typing.Optional[LinkData] = None
    website: typing.Optional[LinkData] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
