# This file was auto-generated by Fern from our API Definition.

import typing

NotificationStandardRequestContentEventType = typing.Union[
    typing.Literal[
        "ApprovedPayment",
        "AuthorizedPayment",
        "DeclinedPayment",
        "OriginatedPayment",
        "SettledPayment",
        "SubscriptionCreated",
        "SubscriptionUpdated",
        "SubscriptionCanceled",
        "SubscriptionCompleted",
        "FundedPayment",
        "VoidedPayment",
        "RefundedPayment",
        "HoldTransaction",
        "ReleasedTransaction",
        "HoldBatch",
        "ReleasedBatch",
        "TransferAdjusted",
        "TransferDisabledCreditFund",
        "TransferDisabledDebitFund",
        "TransferNotAvailableBalance",
        "TransferReadyforRetry",
        "TransferResolved",
        "TransferReturn",
        "TransferSuccess",
        "TransferSuspended",
        "TransferError",
        "SendReceipt",
        "RecoveredTransaction",
        "CreatedApplication",
        "ApprovedApplication",
        "FailedBoardingApplication",
        "SubmittedApplication",
        "ActivatedMerchant",
        "ReceivedChargeBack",
        "ChargebackUpdated",
        "ReceivedRetrieval",
        "RetrievalUpdated",
        "ReceivedAchReturn",
        "HoldingApplication",
        "DeclinedApplication",
        "BoardingApplication",
        "PaypointMoved",
        "FraudAlert",
        "InvoiceSent",
        "InvoicePaid",
        "InvoiceCreated",
        "BillPaid",
        "BillApproved",
        "BillDisApproved",
        "BillCanceled",
        "BillProcessing",
        "CardCreated",
        "CardActivated",
        "CardDeactivated",
        "CardExpired",
        "CardExpiring",
        "CardLimitUpdated",
        "BatchClosed",
        "BatchNotClosed",
        "PayOutFunded",
        "PayOutProcessed",
        "PayOutCanceled",
        "PayOutPaid",
        "PayOutReturned",
        "PayoutSubscriptionCreated",
        "PayoutSubscriptionUpdated",
        "PayoutSubscriptionCanceled",
        "PayoutSubscriptionCompleted",
        "PayoutSubscriptionReminder",
        "importFileReceived",
        "importFileProcessed",
        "importFileError",
        "exportFileSent",
        "exportFileError",
        "UpdatedMerchant",
        "Report",
        "FailedEmailNotification",
        "FailedWebNotification",
        "FailedSMSNotification",
        "UserPasswordExpiring",
        "UserPasswordExpired",
        "TransactionNotFound",
        "SystemAlert",
    ],
    typing.Any,
]
