# This file was auto-generated by Fern from our API Definition.

import enum


class payabliEnvironment(enum.Enum):
    SANDBOX = "https://api-sandbox.payabli.com/api"
    PRODUCTION = "https://api.payabli.com/api"
