# This file was auto-generated by Fern from our API Definition.

import typing

OwnType = typing.Union[
    typing.Literal[
        "Limited Liability Company",
        "Non-Profit Org",
        "Partnership",
        "Private Corp",
        "Public Corp",
        "Tax Exempt",
        "Government",
        "Sole Proprietor",
    ],
    typing.Any,
]
