# This file was auto-generated by Fern from our API Definition.

import typing

from .bill_query_record_2_bill_approvals_item import BillQueryRecord2BillApprovalsItem

BillApprovals = typing.Optional[typing.List[typing.Optional[BillQueryRecord2BillApprovalsItem]]]
