# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PairFiles(UniversalBaseModel):
    original_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="originalName")] = (
        pydantic.Field(default=None)
    )
    """
    Original filename
    """

    zip_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="zipName")] = pydantic.Field(
        default=None
    )
    """
    Filename assigned to zipped file. This is the name to use for reference in the API functions to get files in attachments.
    """

    descriptor: typing.Optional[str] = pydantic.Field(default=None)
    """
    Descriptor of the file.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
