# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PaypointSummary(UniversalBaseModel):
    amount_subs: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="amountSubs")] = None
    amount_tx: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="amountTx")] = None
    count_subs: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="countSubs")] = None
    count_tx: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="countTx")] = None
    customers: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
