# This file was auto-generated by Fern from our API Definition.

import typing

MethodElementSettingsApplePayLanguage = typing.Union[
    typing.Literal[
        "en-US",
        "ar-AB",
        "ca-ES",
        "zh-CN",
        "zh-HK",
        "zh-TW",
        "hr-HR",
        "cs-CZ",
        "da-DK",
        "de-DE",
        "nl-NL",
        "en-AU",
        "en-GB",
        "fi-FI",
        "fr-CA",
        "fr-FR",
        "el-GR",
        "he-IL",
        "hi-IN",
        "hu-HU",
        "id-ID",
        "it-IT",
        "ja-JP",
        "ko-KR",
        "ms-MY",
        "nb-NO",
        "pl-PL",
        "pt-BR",
        "pt-PT",
        "ro-RO",
        "ru-RU",
        "sk-SK",
        "es-MX",
        "es-ES",
        "sv-SE",
        "th-TH",
        "tr-TR",
        "uk-UA",
        "vi-VN",
    ],
    typing.Any,
]
