# This file was auto-generated by Fern from our API Definition.

import typing

Whenrefunded = typing.Union[
    typing.Literal["Exchange Only", "No Refund or Exchange", "More than 30 days", "30 Days or Less"], typing.Any
]
