# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PayabliApiResponseError400ResponseData(UniversalBaseModel):
    """
    Describes the reason for a failed operation and how to resolve it.
    """

    explanation: typing.Optional[str] = pydantic.Field(default=None)
    """
    Describes the reason the operation failed.
    """

    todo_action: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="todoAction")] = pydantic.Field(
        default=None
    )
    """
    Describes how to resolve the error.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
