# This file was auto-generated by Fern from our API Definition.

import typing

NotificationContentReportName = typing.Union[
    typing.Literal["Transaction", "Settlement", "Boarding", "Returned"], typing.Any
]
