# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .auth_capture_payout_response import AuthCapturePayoutResponse
    from .auth_capture_payout_response_data import AuthCapturePayoutResponseData
    from .authorize_payment_method import AuthorizePaymentMethod
    from .authorize_payout_body import AuthorizePayoutBody
    from .capture_all_out_response import CaptureAllOutResponse
    from .capture_all_out_response_response_data_item import CaptureAllOutResponseResponseDataItem
    from .lot_number import LotNumber
    from .operation_result import OperationResult
    from .request_out_authorize_invoice_data import RequestOutAuthorizeInvoiceData
    from .request_out_authorize_payment_details import RequestOutAuthorizePaymentDetails
    from .request_out_authorize_vendor_billing_data import RequestOutAuthorizeVendorBillingData
    from .request_out_authorize_vendor_data import RequestOutAuthorizeVendorData
    from .request_out_authorize_vendor_data_old import RequestOutAuthorizeVendorDataOld
    from .v_card_get_response import VCardGetResponse
    from .v_card_get_response_associated_vendor import VCardGetResponseAssociatedVendor
    from .v_card_get_response_associated_vendor_billing_data import VCardGetResponseAssociatedVendorBillingData
    from .v_card_get_response_associated_vendor_summary import VCardGetResponseAssociatedVendorSummary
    from .v_card_get_response_contact import VCardGetResponseContact
_dynamic_imports: typing.Dict[str, str] = {
    "AuthCapturePayoutResponse": ".auth_capture_payout_response",
    "AuthCapturePayoutResponseData": ".auth_capture_payout_response_data",
    "AuthorizePaymentMethod": ".authorize_payment_method",
    "AuthorizePayoutBody": ".authorize_payout_body",
    "CaptureAllOutResponse": ".capture_all_out_response",
    "CaptureAllOutResponseResponseDataItem": ".capture_all_out_response_response_data_item",
    "LotNumber": ".lot_number",
    "OperationResult": ".operation_result",
    "RequestOutAuthorizeInvoiceData": ".request_out_authorize_invoice_data",
    "RequestOutAuthorizePaymentDetails": ".request_out_authorize_payment_details",
    "RequestOutAuthorizeVendorBillingData": ".request_out_authorize_vendor_billing_data",
    "RequestOutAuthorizeVendorData": ".request_out_authorize_vendor_data",
    "RequestOutAuthorizeVendorDataOld": ".request_out_authorize_vendor_data_old",
    "VCardGetResponse": ".v_card_get_response",
    "VCardGetResponseAssociatedVendor": ".v_card_get_response_associated_vendor",
    "VCardGetResponseAssociatedVendorBillingData": ".v_card_get_response_associated_vendor_billing_data",
    "VCardGetResponseAssociatedVendorSummary": ".v_card_get_response_associated_vendor_summary",
    "VCardGetResponseContact": ".v_card_get_response_contact",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AuthCapturePayoutResponse",
    "AuthCapturePayoutResponseData",
    "AuthorizePaymentMethod",
    "AuthorizePayoutBody",
    "CaptureAllOutResponse",
    "CaptureAllOutResponseResponseDataItem",
    "LotNumber",
    "OperationResult",
    "RequestOutAuthorizeInvoiceData",
    "RequestOutAuthorizePaymentDetails",
    "RequestOutAuthorizeVendorBillingData",
    "RequestOutAuthorizeVendorData",
    "RequestOutAuthorizeVendorDataOld",
    "VCardGetResponse",
    "VCardGetResponseAssociatedVendor",
    "VCardGetResponseAssociatedVendorBillingData",
    "VCardGetResponseAssociatedVendorSummary",
    "VCardGetResponseContact",
]
